summaryrefslogtreecommitdiff
path: root/usr.bin/top/top.c
diff options
context:
space:
mode:
authorPhilip Guenther <guenther@cvs.openbsd.org>2013-01-14 21:34:00 +0000
committerPhilip Guenther <guenther@cvs.openbsd.org>2013-01-14 21:34:00 +0000
commit1f40f9f21f0354c37a735df8bccb46f15ab0b5d3 (patch)
tree22833d9be5fb98fee25a9bed22f414fc78a055a1 /usr.bin/top/top.c
parentf0178e58b56f0f2bcbbaa3ecd0715902fe2b8b8b (diff)
When showing threads, say so. Fix up some comments and names at the same time.
original diff by zhuk@ ok jsing@ mpi@ zhuk@
Diffstat (limited to 'usr.bin/top/top.c')
-rw-r--r--usr.bin/top/top.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/usr.bin/top/top.c b/usr.bin/top/top.c
index 377c9834638..086a830e1d7 100644
--- a/usr.bin/top/top.c
+++ b/usr.bin/top/top.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: top.c,v 1.79 2012/06/08 13:41:16 lum Exp $ */
+/* $OpenBSD: top.c,v 1.80 2013/01/14 21:33:59 guenther Exp $ */
/*
* Top users/processes display for Unix
@@ -452,8 +452,9 @@ restart:
time(&curr_time);
i_timeofday(&curr_time);
- /* display process state breakdown */
- i_procstates(system_info.p_total, system_info.procstates);
+ /* display process/threads state breakdown */
+ i_procstates(system_info.p_total, system_info.procstates,
+ ps.threads);
/* display the cpu state percentage breakdown */
i_cpustates(system_info.cpustates);